==> mingw-w64-qt6-base-6.7.0-1-any.pkg.tar.zst: usr/x86_64-w64-mingw32/lib/cmake/Qt6ExampleIconsPrivate/Qt6ExampleIconsPrivateTargets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::ExampleIconsPrivate" for configuration "None"
set_property(TARGET Qt6::ExampleIconsPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Qt6::ExampleIconsPrivate PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libQt6ExampleIcons.a"
  )

list(APPEND _cmake_import_check_targets Qt6::ExampleIconsPrivate )
list(APPEND _cmake_import_check_files_for_Qt6::ExampleIconsPrivate "${_IMPORT_PREFIX}/lib/libQt6ExampleIcons.a" )

# Import target "Qt6::ExampleIconsPrivate_resources_1" for configuration "None"
set_property(TARGET Qt6::ExampleIconsPrivate_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Qt6::ExampleIconsPrivate_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_OBJECTS_NONE "${_IMPORT_PREFIX}/lib/objects-None/ExampleIconsPrivate_resources_1/.rcc/qrc_example_icons_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::ExampleIconsPrivate_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::ExampleIconsPrivate_resources_1 "${_IMPORT_PREFIX}/lib/objects-None/ExampleIconsPrivate_resources_1/.rcc/qrc_example_icons_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-qt6-base-6.9.1-1-any.pkg.tar.zst: usr/x86_64-w64-mingw32/lib/cmake/Qt6ExampleIconsPrivate/Qt6ExampleIconsPrivateTargets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::ExampleIconsPrivate" for configuration "None"
set_property(TARGET Qt6::ExampleIconsPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Qt6::ExampleIconsPrivate PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libQt6ExampleIcons.a"
  )

list(APPEND _cmake_import_check_targets Qt6::ExampleIconsPrivate )
list(APPEND _cmake_import_check_files_for_Qt6::ExampleIconsPrivate "${_IMPORT_PREFIX}/lib/libQt6ExampleIcons.a" )

# Import target "Qt6::ExampleIconsPrivate_resources_1" for configuration "None"
set_property(TARGET Qt6::ExampleIconsPrivate_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Qt6::ExampleIconsPrivate_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_OBJECTS_NONE "${_IMPORT_PREFIX}/lib/objects-None/ExampleIconsPrivate_resources_1/.qt/rcc/qrc_example_icons_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::ExampleIconsPrivate_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::ExampleIconsPrivate_resources_1 "${_IMPORT_PREFIX}/lib/objects-None/ExampleIconsPrivate_resources_1/.qt/rcc/qrc_example_icons_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
